==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/FrameFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FrameFluent<A extends FrameFluent<A>> extends BaseFluent<A>{
  public FrameFluent() {
  }
  public FrameFluent(Frame instance) {
    instance = (instance != null ? instance : new Frame());

    if (instance != null) {
      this.withFuncname(instance.getFuncname());
      this.withParameters(instance.getParameters());
      this.withPredicate(instance.getPredicate());
      this.withFuncname(instance.getFuncname());
      this.withParameters(instance.getParameters());
      this.withPredicate(instance.getPredicate());
    }
  }
  private String funcname;
  private String parameters;
  private String predicate;
  public String getFuncname() {
    return this.funcname;
  }
  public A withFuncname(String funcname) {
    this.funcname=funcname; return (A) this;
  }
  public boolean hasFuncname() {
    return this.funcname != null;
  }
  public String getParameters() {
    return this.parameters;
  }
  public A withParameters(String parameters) {
    this.parameters=parameters; return (A) this;
  }
  public boolean hasParameters() {
    return this.parameters != null;
  }
  public String getPredicate() {
    return this.predicate;
  }
  public A withPredicate(String predicate) {
    this.predicate=predicate; return (A) this;
  }
  public boolean hasPredicate() {
    return this.predicate != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FrameFluent that = (FrameFluent) o;
    if (!java.util.Objects.equals(funcname, that.funcname)) return false;

    if (!java.util.Objects.equals(parameters, that.parameters)) return false;

    if (!java.util.Objects.equals(predicate, that.predicate)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(funcname,  parameters,  predicate,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (funcname != null) { sb.append("funcname:"); sb.append(funcname + ","); }
    if (parameters != null) { sb.append("parameters:"); sb.append(parameters + ","); }
    if (predicate != null) { sb.append("predicate:"); sb.append(predicate); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/FrameFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FrameFluent<A extends FrameFluent<A>> extends BaseFluent<A>{
  public FrameFluent() {
  }
  
  public FrameFluent(Frame instance) {
    this.copyInstance(instance);
  }
  private String funcname;
  private String parameters;
  private String predicate;
  
  protected void copyInstance(Frame instance) {
    instance = (instance != null ? instance : new Frame());
  
    if (instance != null) {
        this.withFuncname(instance.getFuncname());
        this.withParameters(instance.getParameters());
        this.withPredicate(instance.getPredicate());
        this.withFuncname(instance.getFuncname());
        this.withParameters(instance.getParameters());
        this.withPredicate(instance.getPredicate());
      }
  }
  
  public String getFuncname() {
    return this.funcname;
  }
  
  public A withFuncname(String funcname) {
    this.funcname=funcname; return (A) this;
  }
  
  public boolean hasFuncname() {
    return this.funcname != null;
  }
  
  public String getParameters() {
    return this.parameters;
  }
  
  public A withParameters(String parameters) {
    this.parameters=parameters; return (A) this;
  }
  
  public boolean hasParameters() {
    return this.parameters != null;
  }
  
  public String getPredicate() {
    return this.predicate;
  }
  
  public A withPredicate(String predicate) {
    this.predicate=predicate; return (A) this;
  }
  
  public boolean hasPredicate() {
    return this.predicate != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FrameFluent that = (FrameFluent) o;
    if (!java.util.Objects.equals(funcname, that.funcname)) return false;
  
    if (!java.util.Objects.equals(parameters, that.parameters)) return false;
  
    if (!java.util.Objects.equals(predicate, that.predicate)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(funcname,  parameters,  predicate,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (funcname != null) { sb.append("funcname:"); sb.append(funcname + ","); }
    if (parameters != null) { sb.append("parameters:"); sb.append(parameters + ","); }
    if (predicate != null) { sb.append("predicate:"); sb.append(predicate); }
    sb.append("}");
    return sb.toString();
  }
  

}
